# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: milvus.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import schema_pb2 as schema__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='milvus.proto',
  package='milvus.proto.milvus',
  syntax='proto3',
  serialized_options=_b('Z@github.com/zilliztech/milvus-distributed/internal/proto/milvuspb'),
  serialized_pb=_b('\n\x0cmilvus.proto\x12\x13milvus.proto.milvus\x1a\x0c\x63ommon.proto\x1a\x0cschema.proto\"\x7f\n\x17\x43reateCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x0e\n\x06schema\x18\x04 \x01(\x0c\"m\n\x15\x44ropCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\"l\n\x14HasCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\"J\n\x0c\x42oolResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\r\n\x05value\x18\x02 \x01(\x08\"L\n\x0eStringResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\r\n\x05value\x18\x02 \x01(\t\"q\n\x19\x44\x65scribeCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\"\x96\x01\n\x1a\x44\x65scribeCollectionResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x35\n\x06schema\x18\x02 \x01(\x0b\x32%.milvus.proto.schema.CollectionSchema\x12\x14\n\x0c\x63ollectionID\x18\x03 \x01(\x03\"m\n\x15LoadCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\"p\n\x18ReleaseCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\"n\n\x16\x43ollectionStatsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\"x\n\x17\x43ollectionStatsResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x30\n\x05stats\x18\x02 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"T\n\x15ShowCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\"_\n\x16ShowCollectionResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x18\n\x10\x63ollection_names\x18\x02 \x03(\t\"\x86\x01\n\x16\x43reatePartitionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\"\x84\x01\n\x14\x44ropPartitionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\"\x83\x01\n\x13HasPartitionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\"\x84\x01\n\x13LoadPartitonRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x17\n\x0fpartition_names\x18\x04 \x03(\t\"\x88\x01\n\x17ReleasePartitionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x17\n\x0fpartition_names\x18\x04 \x03(\t\"\x85\x01\n\x15PartitionStatsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\"w\n\x16PartitionStatsResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x30\n\x05stats\x18\x02 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"\x82\x01\n\x14ShowPartitionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x14\n\x0c\x63ollectionID\x18\x04 \x01(\x03\"s\n\x15ShowPartitionResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x17\n\x0fpartition_names\x18\x02 \x03(\t\x12\x14\n\x0cpartitionIDs\x18\x03 \x03(\x03\"m\n\x16\x44\x65scribeSegmentRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x11\n\tsegmentID\x18\x03 \x01(\x03\"h\n\x17\x44\x65scribeSegmentResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0f\n\x07indexID\x18\x02 \x01(\x03\x12\x0f\n\x07\x62uildID\x18\x03 \x01(\x03\"k\n\x12ShowSegmentRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x13\n\x0bpartitionID\x18\x03 \x01(\x03\"V\n\x13ShowSegmentResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x12\n\nsegmentIDs\x18\x02 \x03(\x03\"\xb7\x01\n\x12\x43reateIndexRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\nfield_name\x18\x04 \x01(\t\x12\x37\n\x0c\x65xtra_params\x18\x05 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"\x94\x01\n\x14\x44\x65scribeIndexRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\nfield_name\x18\x04 \x01(\t\x12\x12\n\nindex_name\x18\x05 \x01(\t\"j\n\x10IndexDescription\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x0f\n\x07indexID\x18\x02 \x01(\x03\x12\x31\n\x06params\x18\x03 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"\x87\x01\n\x15\x44\x65scribeIndexResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x41\n\x12index_descriptions\x18\x02 \x03(\x0b\x32%.milvus.proto.milvus.IndexDescription\"\x91\x01\n\x11IndexStateRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\nfield_name\x18\x04 \x01(\t\x12\x12\n\nindex_name\x18\x05 \x01(\t\"q\n\x12IndexStateResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12.\n\x05state\x18\x02 \x01(\x0e\x32\x1f.milvus.proto.common.IndexState\"\x90\x01\n\x10\x44ropIndexRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\nfield_name\x18\x04 \x01(\t\x12\x12\n\nindex_name\x18\x05 \x01(\t\"\xbd\x01\n\rInsertRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\x12+\n\x08row_data\x18\x05 \x03(\x0b\x32\x19.milvus.proto.common.Blob\x12\x11\n\thash_keys\x18\x06 \x03(\r\"e\n\x0eInsertResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x13\n\x0browID_begin\x18\x02 \x01(\x03\x12\x11\n\trowID_end\x18\x03 \x01(\x03\"c\n\x10PlaceholderValue\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x32\n\x04type\x18\x02 \x01(\x0e\x32$.milvus.proto.milvus.PlaceholderType\x12\x0e\n\x06values\x18\x03 \x03(\x0c\"O\n\x10PlaceholderGroup\x12;\n\x0cplaceholders\x18\x01 \x03(\x0b\x32%.milvus.proto.milvus.PlaceholderValue\"\xa6\x01\n\rSearchRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x17\n\x0fpartition_names\x18\x04 \x03(\t\x12\x0b\n\x03\x64sl\x18\x05 \x01(\t\x12\x19\n\x11placeholder_group\x18\x06 \x01(\x0c\"5\n\x04Hits\x12\x0b\n\x03IDs\x18\x01 \x03(\x03\x12\x10\n\x08row_data\x18\x02 \x03(\x0c\x12\x0e\n\x06scores\x18\x03 \x03(\x02\"J\n\rSearchResults\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0c\n\x04hits\x18\x02 \x03(\x0c\"e\n\x0c\x46lushRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x18\n\x10\x63ollection_names\x18\x03 \x03(\t\"\xe9\x01\n\x15PersistentSegmentInfo\x12\x11\n\tsegmentID\x18\x01 \x01(\x03\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x13\n\x0bpartitionID\x18\x03 \x01(\x03\x12\x11\n\topen_time\x18\x04 \x01(\x04\x12\x13\n\x0bsealed_time\x18\x05 \x01(\x04\x12\x14\n\x0c\x66lushed_time\x18\x06 \x01(\x04\x12\x10\n\x08num_rows\x18\x07 \x01(\x03\x12\x10\n\x08mem_size\x18\x08 \x01(\x03\x12\x30\n\x05state\x18\t \x01(\x0e\x32!.milvus.proto.common.SegmentState\"r\n\x1cPersistentSegmentInfoRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0e\n\x06\x64\x62Name\x18\x02 \x01(\t\x12\x16\n\x0e\x63ollectionName\x18\x03 \x01(\t\"\x87\x01\n\x1dPersistentSegmentInfoResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x39\n\x05infos\x18\x02 \x03(\x0b\x32*.milvus.proto.milvus.PersistentSegmentInfo\"\x99\x01\n\x10QuerySegmentInfo\x12\x11\n\tsegmentID\x18\x01 \x01(\x03\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x13\n\x0bpartitionID\x18\x03 \x01(\x03\x12\x10\n\x08mem_size\x18\x04 \x01(\x03\x12\x10\n\x08num_rows\x18\x05 \x01(\x03\x12\x12\n\nindex_name\x18\x06 \x01(\t\x12\x0f\n\x07indexID\x18\x07 \x01(\x03\"m\n\x17QuerySegmentInfoRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0e\n\x06\x64\x62Name\x18\x02 \x01(\t\x12\x16\n\x0e\x63ollectionName\x18\x03 \x01(\t\"}\n\x18QuerySegmentInfoResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x34\n\x05infos\x18\x02 \x03(\x0b\x32%.milvus.proto.milvus.QuerySegmentInfo\"r\n\x14RegisterLinkResponse\x12-\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.Address\x12+\n\x06status\x18\x02 \x01(\x0b\x32\x1b.milvus.proto.common.Status*@\n\x0fPlaceholderType\x12\x08\n\x04NONE\x10\x00\x12\x11\n\rVECTOR_BINARY\x10\x64\x12\x10\n\x0cVECTOR_FLOAT\x10\x65\x32\xbe\x13\n\rMilvusService\x12_\n\x10\x43reateCollection\x12,.milvus.proto.milvus.CreateCollectionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12[\n\x0e\x44ropCollection\x12*.milvus.proto.milvus.DropCollectionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12_\n\rHasCollection\x12).milvus.proto.milvus.HasCollectionRequest\x1a!.milvus.proto.milvus.BoolResponse\"\x00\x12[\n\x0eLoadCollection\x12*.milvus.proto.milvus.LoadCollectionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12\x61\n\x11ReleaseCollection\x12-.milvus.proto.milvus.ReleaseCollectionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12w\n\x12\x44\x65scribeCollection\x12..milvus.proto.milvus.DescribeCollectionRequest\x1a/.milvus.proto.milvus.DescribeCollectionResponse\"\x00\x12v\n\x17GetCollectionStatistics\x12+.milvus.proto.milvus.CollectionStatsRequest\x1a,.milvus.proto.milvus.CollectionStatsResponse\"\x00\x12l\n\x0fShowCollections\x12*.milvus.proto.milvus.ShowCollectionRequest\x1a+.milvus.proto.milvus.ShowCollectionResponse\"\x00\x12]\n\x0f\x43reatePartition\x12+.milvus.proto.milvus.CreatePartitionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12Y\n\rDropPartition\x12).milvus.proto.milvus.DropPartitionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12]\n\x0cHasPartition\x12(.milvus.proto.milvus.HasPartitionRequest\x1a!.milvus.proto.milvus.BoolResponse\"\x00\x12Y\n\x0eLoadPartitions\x12(.milvus.proto.milvus.LoadPartitonRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12`\n\x11ReleasePartitions\x12,.milvus.proto.milvus.ReleasePartitionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12s\n\x16GetPartitionStatistics\x12*.milvus.proto.milvus.PartitionStatsRequest\x1a+.milvus.proto.milvus.PartitionStatsResponse\"\x00\x12i\n\x0eShowPartitions\x12).milvus.proto.milvus.ShowPartitionRequest\x1a*.milvus.proto.milvus.ShowPartitionResponse\"\x00\x12U\n\x0b\x43reateIndex\x12\'.milvus.proto.milvus.CreateIndexRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12h\n\rDescribeIndex\x12).milvus.proto.milvus.DescribeIndexRequest\x1a*.milvus.proto.milvus.DescribeIndexResponse\"\x00\x12\x62\n\rGetIndexState\x12&.milvus.proto.milvus.IndexStateRequest\x1a\'.milvus.proto.milvus.IndexStateResponse\"\x00\x12Q\n\tDropIndex\x12%.milvus.proto.milvus.DropIndexRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12S\n\x06Insert\x12\".milvus.proto.milvus.InsertRequest\x1a#.milvus.proto.milvus.InsertResponse\"\x00\x12R\n\x06Search\x12\".milvus.proto.milvus.SearchRequest\x1a\".milvus.proto.milvus.SearchResults\"\x00\x12I\n\x05\x46lush\x12!.milvus.proto.milvus.FlushRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12Q\n\x0cGetDdChannel\x12\x1a.milvus.proto.common.Empty\x1a#.milvus.proto.milvus.StringResponse\"\x00\x12\x83\x01\n\x18GetPersistentSegmentInfo\x12\x31.milvus.proto.milvus.PersistentSegmentInfoRequest\x1a\x32.milvus.proto.milvus.PersistentSegmentInfoResponse\"\x00\x12t\n\x13GetQuerySegmentInfo\x12,.milvus.proto.milvus.QuerySegmentInfoRequest\x1a-.milvus.proto.milvus.QuerySegmentInfoResponse\"\x00\x32g\n\x0cProxyService\x12W\n\x0cRegisterLink\x12\x1a.milvus.proto.common.Empty\x1a).milvus.proto.milvus.RegisterLinkResponse\"\x00\x42\x42Z@github.com/zilliztech/milvus-distributed/internal/proto/milvuspbb\x06proto3')
  ,
  dependencies=[common__pb2.DESCRIPTOR,schema__pb2.DESCRIPTOR,])

_PLACEHOLDERTYPE = _descriptor.EnumDescriptor(
  name='PlaceholderType',
  full_name='milvus.proto.milvus.PlaceholderType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VECTOR_BINARY', index=1, number=100,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VECTOR_FLOAT', index=2, number=101,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5953,
  serialized_end=6017,
)
_sym_db.RegisterEnumDescriptor(_PLACEHOLDERTYPE)

PlaceholderType = enum_type_wrapper.EnumTypeWrapper(_PLACEHOLDERTYPE)
NONE = 0
VECTOR_BINARY = 100
VECTOR_FLOAT = 101



_CREATECOLLECTIONREQUEST = _descriptor.Descriptor(
  name='CreateCollectionRequest',
  full_name='milvus.proto.milvus.CreateCollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.CreateCollectionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.CreateCollectionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.CreateCollectionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='milvus.proto.milvus.CreateCollectionRequest.schema', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=192,
)


_DROPCOLLECTIONREQUEST = _descriptor.Descriptor(
  name='DropCollectionRequest',
  full_name='milvus.proto.milvus.DropCollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.DropCollectionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.DropCollectionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.DropCollectionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=303,
)


_HASCOLLECTIONREQUEST = _descriptor.Descriptor(
  name='HasCollectionRequest',
  full_name='milvus.proto.milvus.HasCollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.HasCollectionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.HasCollectionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.HasCollectionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=413,
)


_BOOLRESPONSE = _descriptor.Descriptor(
  name='BoolResponse',
  full_name='milvus.proto.milvus.BoolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.BoolResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='milvus.proto.milvus.BoolResponse.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=489,
)


_STRINGRESPONSE = _descriptor.Descriptor(
  name='StringResponse',
  full_name='milvus.proto.milvus.StringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.StringResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='milvus.proto.milvus.StringResponse.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=567,
)


_DESCRIBECOLLECTIONREQUEST = _descriptor.Descriptor(
  name='DescribeCollectionRequest',
  full_name='milvus.proto.milvus.DescribeCollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.DescribeCollectionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.DescribeCollectionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.DescribeCollectionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=682,
)


_DESCRIBECOLLECTIONRESPONSE = _descriptor.Descriptor(
  name='DescribeCollectionResponse',
  full_name='milvus.proto.milvus.DescribeCollectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.DescribeCollectionResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='milvus.proto.milvus.DescribeCollectionResponse.schema', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionID', full_name='milvus.proto.milvus.DescribeCollectionResponse.collectionID', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=685,
  serialized_end=835,
)


_LOADCOLLECTIONREQUEST = _descriptor.Descriptor(
  name='LoadCollectionRequest',
  full_name='milvus.proto.milvus.LoadCollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.LoadCollectionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.LoadCollectionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.LoadCollectionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=837,
  serialized_end=946,
)


_RELEASECOLLECTIONREQUEST = _descriptor.Descriptor(
  name='ReleaseCollectionRequest',
  full_name='milvus.proto.milvus.ReleaseCollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.ReleaseCollectionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.ReleaseCollectionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.ReleaseCollectionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=1060,
)


_COLLECTIONSTATSREQUEST = _descriptor.Descriptor(
  name='CollectionStatsRequest',
  full_name='milvus.proto.milvus.CollectionStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.CollectionStatsRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.CollectionStatsRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.CollectionStatsRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1062,
  serialized_end=1172,
)


_COLLECTIONSTATSRESPONSE = _descriptor.Descriptor(
  name='CollectionStatsResponse',
  full_name='milvus.proto.milvus.CollectionStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.CollectionStatsResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='milvus.proto.milvus.CollectionStatsResponse.stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1174,
  serialized_end=1294,
)


_SHOWCOLLECTIONREQUEST = _descriptor.Descriptor(
  name='ShowCollectionRequest',
  full_name='milvus.proto.milvus.ShowCollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.ShowCollectionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.ShowCollectionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1296,
  serialized_end=1380,
)


_SHOWCOLLECTIONRESPONSE = _descriptor.Descriptor(
  name='ShowCollectionResponse',
  full_name='milvus.proto.milvus.ShowCollectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.ShowCollectionResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_names', full_name='milvus.proto.milvus.ShowCollectionResponse.collection_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1382,
  serialized_end=1477,
)


_CREATEPARTITIONREQUEST = _descriptor.Descriptor(
  name='CreatePartitionRequest',
  full_name='milvus.proto.milvus.CreatePartitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.CreatePartitionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.CreatePartitionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.CreatePartitionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_name', full_name='milvus.proto.milvus.CreatePartitionRequest.partition_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1480,
  serialized_end=1614,
)


_DROPPARTITIONREQUEST = _descriptor.Descriptor(
  name='DropPartitionRequest',
  full_name='milvus.proto.milvus.DropPartitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.DropPartitionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.DropPartitionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.DropPartitionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_name', full_name='milvus.proto.milvus.DropPartitionRequest.partition_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1617,
  serialized_end=1749,
)


_HASPARTITIONREQUEST = _descriptor.Descriptor(
  name='HasPartitionRequest',
  full_name='milvus.proto.milvus.HasPartitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.HasPartitionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.HasPartitionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.HasPartitionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_name', full_name='milvus.proto.milvus.HasPartitionRequest.partition_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1752,
  serialized_end=1883,
)


_LOADPARTITONREQUEST = _descriptor.Descriptor(
  name='LoadPartitonRequest',
  full_name='milvus.proto.milvus.LoadPartitonRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.LoadPartitonRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.LoadPartitonRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.LoadPartitonRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_names', full_name='milvus.proto.milvus.LoadPartitonRequest.partition_names', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1886,
  serialized_end=2018,
)


_RELEASEPARTITIONREQUEST = _descriptor.Descriptor(
  name='ReleasePartitionRequest',
  full_name='milvus.proto.milvus.ReleasePartitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.ReleasePartitionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.ReleasePartitionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.ReleasePartitionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_names', full_name='milvus.proto.milvus.ReleasePartitionRequest.partition_names', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2021,
  serialized_end=2157,
)


_PARTITIONSTATSREQUEST = _descriptor.Descriptor(
  name='PartitionStatsRequest',
  full_name='milvus.proto.milvus.PartitionStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.PartitionStatsRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.PartitionStatsRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.PartitionStatsRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_name', full_name='milvus.proto.milvus.PartitionStatsRequest.partition_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2160,
  serialized_end=2293,
)


_PARTITIONSTATSRESPONSE = _descriptor.Descriptor(
  name='PartitionStatsResponse',
  full_name='milvus.proto.milvus.PartitionStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.PartitionStatsResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='milvus.proto.milvus.PartitionStatsResponse.stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2295,
  serialized_end=2414,
)


_SHOWPARTITIONREQUEST = _descriptor.Descriptor(
  name='ShowPartitionRequest',
  full_name='milvus.proto.milvus.ShowPartitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.ShowPartitionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.ShowPartitionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.ShowPartitionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionID', full_name='milvus.proto.milvus.ShowPartitionRequest.collectionID', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2417,
  serialized_end=2547,
)


_SHOWPARTITIONRESPONSE = _descriptor.Descriptor(
  name='ShowPartitionResponse',
  full_name='milvus.proto.milvus.ShowPartitionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.ShowPartitionResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_names', full_name='milvus.proto.milvus.ShowPartitionResponse.partition_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitionIDs', full_name='milvus.proto.milvus.ShowPartitionResponse.partitionIDs', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2549,
  serialized_end=2664,
)


_DESCRIBESEGMENTREQUEST = _descriptor.Descriptor(
  name='DescribeSegmentRequest',
  full_name='milvus.proto.milvus.DescribeSegmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.DescribeSegmentRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionID', full_name='milvus.proto.milvus.DescribeSegmentRequest.collectionID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='segmentID', full_name='milvus.proto.milvus.DescribeSegmentRequest.segmentID', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2666,
  serialized_end=2775,
)


_DESCRIBESEGMENTRESPONSE = _descriptor.Descriptor(
  name='DescribeSegmentResponse',
  full_name='milvus.proto.milvus.DescribeSegmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.DescribeSegmentResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indexID', full_name='milvus.proto.milvus.DescribeSegmentResponse.indexID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buildID', full_name='milvus.proto.milvus.DescribeSegmentResponse.buildID', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2777,
  serialized_end=2881,
)


_SHOWSEGMENTREQUEST = _descriptor.Descriptor(
  name='ShowSegmentRequest',
  full_name='milvus.proto.milvus.ShowSegmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.ShowSegmentRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionID', full_name='milvus.proto.milvus.ShowSegmentRequest.collectionID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitionID', full_name='milvus.proto.milvus.ShowSegmentRequest.partitionID', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2883,
  serialized_end=2990,
)


_SHOWSEGMENTRESPONSE = _descriptor.Descriptor(
  name='ShowSegmentResponse',
  full_name='milvus.proto.milvus.ShowSegmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.ShowSegmentResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='segmentIDs', full_name='milvus.proto.milvus.ShowSegmentResponse.segmentIDs', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2992,
  serialized_end=3078,
)


_CREATEINDEXREQUEST = _descriptor.Descriptor(
  name='CreateIndexRequest',
  full_name='milvus.proto.milvus.CreateIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.CreateIndexRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.CreateIndexRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.CreateIndexRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.milvus.CreateIndexRequest.field_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_params', full_name='milvus.proto.milvus.CreateIndexRequest.extra_params', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3081,
  serialized_end=3264,
)


_DESCRIBEINDEXREQUEST = _descriptor.Descriptor(
  name='DescribeIndexRequest',
  full_name='milvus.proto.milvus.DescribeIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.DescribeIndexRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.DescribeIndexRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.DescribeIndexRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.milvus.DescribeIndexRequest.field_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_name', full_name='milvus.proto.milvus.DescribeIndexRequest.index_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3267,
  serialized_end=3415,
)


_INDEXDESCRIPTION = _descriptor.Descriptor(
  name='IndexDescription',
  full_name='milvus.proto.milvus.IndexDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index_name', full_name='milvus.proto.milvus.IndexDescription.index_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indexID', full_name='milvus.proto.milvus.IndexDescription.indexID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='milvus.proto.milvus.IndexDescription.params', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3417,
  serialized_end=3523,
)


_DESCRIBEINDEXRESPONSE = _descriptor.Descriptor(
  name='DescribeIndexResponse',
  full_name='milvus.proto.milvus.DescribeIndexResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.DescribeIndexResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_descriptions', full_name='milvus.proto.milvus.DescribeIndexResponse.index_descriptions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3526,
  serialized_end=3661,
)


_INDEXSTATEREQUEST = _descriptor.Descriptor(
  name='IndexStateRequest',
  full_name='milvus.proto.milvus.IndexStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.IndexStateRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.IndexStateRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.IndexStateRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.milvus.IndexStateRequest.field_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_name', full_name='milvus.proto.milvus.IndexStateRequest.index_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3664,
  serialized_end=3809,
)


_INDEXSTATERESPONSE = _descriptor.Descriptor(
  name='IndexStateResponse',
  full_name='milvus.proto.milvus.IndexStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.IndexStateResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='milvus.proto.milvus.IndexStateResponse.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3811,
  serialized_end=3924,
)


_DROPINDEXREQUEST = _descriptor.Descriptor(
  name='DropIndexRequest',
  full_name='milvus.proto.milvus.DropIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.DropIndexRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.DropIndexRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.DropIndexRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.milvus.DropIndexRequest.field_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_name', full_name='milvus.proto.milvus.DropIndexRequest.index_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3927,
  serialized_end=4071,
)


_INSERTREQUEST = _descriptor.Descriptor(
  name='InsertRequest',
  full_name='milvus.proto.milvus.InsertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.InsertRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.InsertRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.InsertRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_name', full_name='milvus.proto.milvus.InsertRequest.partition_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_data', full_name='milvus.proto.milvus.InsertRequest.row_data', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash_keys', full_name='milvus.proto.milvus.InsertRequest.hash_keys', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4074,
  serialized_end=4263,
)


_INSERTRESPONSE = _descriptor.Descriptor(
  name='InsertResponse',
  full_name='milvus.proto.milvus.InsertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.InsertResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rowID_begin', full_name='milvus.proto.milvus.InsertResponse.rowID_begin', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rowID_end', full_name='milvus.proto.milvus.InsertResponse.rowID_end', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4265,
  serialized_end=4366,
)


_PLACEHOLDERVALUE = _descriptor.Descriptor(
  name='PlaceholderValue',
  full_name='milvus.proto.milvus.PlaceholderValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='milvus.proto.milvus.PlaceholderValue.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='milvus.proto.milvus.PlaceholderValue.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='milvus.proto.milvus.PlaceholderValue.values', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4368,
  serialized_end=4467,
)


_PLACEHOLDERGROUP = _descriptor.Descriptor(
  name='PlaceholderGroup',
  full_name='milvus.proto.milvus.PlaceholderGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='placeholders', full_name='milvus.proto.milvus.PlaceholderGroup.placeholders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4469,
  serialized_end=4548,
)


_SEARCHREQUEST = _descriptor.Descriptor(
  name='SearchRequest',
  full_name='milvus.proto.milvus.SearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.SearchRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.SearchRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.SearchRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_names', full_name='milvus.proto.milvus.SearchRequest.partition_names', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dsl', full_name='milvus.proto.milvus.SearchRequest.dsl', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholder_group', full_name='milvus.proto.milvus.SearchRequest.placeholder_group', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4551,
  serialized_end=4717,
)


_HITS = _descriptor.Descriptor(
  name='Hits',
  full_name='milvus.proto.milvus.Hits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='IDs', full_name='milvus.proto.milvus.Hits.IDs', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_data', full_name='milvus.proto.milvus.Hits.row_data', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scores', full_name='milvus.proto.milvus.Hits.scores', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4719,
  serialized_end=4772,
)


_SEARCHRESULTS = _descriptor.Descriptor(
  name='SearchResults',
  full_name='milvus.proto.milvus.SearchResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.SearchResults.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hits', full_name='milvus.proto.milvus.SearchResults.hits', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4774,
  serialized_end=4848,
)


_FLUSHREQUEST = _descriptor.Descriptor(
  name='FlushRequest',
  full_name='milvus.proto.milvus.FlushRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.FlushRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.FlushRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_names', full_name='milvus.proto.milvus.FlushRequest.collection_names', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4850,
  serialized_end=4951,
)


_PERSISTENTSEGMENTINFO = _descriptor.Descriptor(
  name='PersistentSegmentInfo',
  full_name='milvus.proto.milvus.PersistentSegmentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='segmentID', full_name='milvus.proto.milvus.PersistentSegmentInfo.segmentID', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionID', full_name='milvus.proto.milvus.PersistentSegmentInfo.collectionID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitionID', full_name='milvus.proto.milvus.PersistentSegmentInfo.partitionID', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_time', full_name='milvus.proto.milvus.PersistentSegmentInfo.open_time', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sealed_time', full_name='milvus.proto.milvus.PersistentSegmentInfo.sealed_time', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flushed_time', full_name='milvus.proto.milvus.PersistentSegmentInfo.flushed_time', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_rows', full_name='milvus.proto.milvus.PersistentSegmentInfo.num_rows', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mem_size', full_name='milvus.proto.milvus.PersistentSegmentInfo.mem_size', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='milvus.proto.milvus.PersistentSegmentInfo.state', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4954,
  serialized_end=5187,
)


_PERSISTENTSEGMENTINFOREQUEST = _descriptor.Descriptor(
  name='PersistentSegmentInfoRequest',
  full_name='milvus.proto.milvus.PersistentSegmentInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.PersistentSegmentInfoRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dbName', full_name='milvus.proto.milvus.PersistentSegmentInfoRequest.dbName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionName', full_name='milvus.proto.milvus.PersistentSegmentInfoRequest.collectionName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5189,
  serialized_end=5303,
)


_PERSISTENTSEGMENTINFORESPONSE = _descriptor.Descriptor(
  name='PersistentSegmentInfoResponse',
  full_name='milvus.proto.milvus.PersistentSegmentInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.PersistentSegmentInfoResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infos', full_name='milvus.proto.milvus.PersistentSegmentInfoResponse.infos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5306,
  serialized_end=5441,
)


_QUERYSEGMENTINFO = _descriptor.Descriptor(
  name='QuerySegmentInfo',
  full_name='milvus.proto.milvus.QuerySegmentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='segmentID', full_name='milvus.proto.milvus.QuerySegmentInfo.segmentID', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionID', full_name='milvus.proto.milvus.QuerySegmentInfo.collectionID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitionID', full_name='milvus.proto.milvus.QuerySegmentInfo.partitionID', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mem_size', full_name='milvus.proto.milvus.QuerySegmentInfo.mem_size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_rows', full_name='milvus.proto.milvus.QuerySegmentInfo.num_rows', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_name', full_name='milvus.proto.milvus.QuerySegmentInfo.index_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indexID', full_name='milvus.proto.milvus.QuerySegmentInfo.indexID', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5444,
  serialized_end=5597,
)


_QUERYSEGMENTINFOREQUEST = _descriptor.Descriptor(
  name='QuerySegmentInfoRequest',
  full_name='milvus.proto.milvus.QuerySegmentInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.QuerySegmentInfoRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dbName', full_name='milvus.proto.milvus.QuerySegmentInfoRequest.dbName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionName', full_name='milvus.proto.milvus.QuerySegmentInfoRequest.collectionName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5599,
  serialized_end=5708,
)


_QUERYSEGMENTINFORESPONSE = _descriptor.Descriptor(
  name='QuerySegmentInfoResponse',
  full_name='milvus.proto.milvus.QuerySegmentInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.QuerySegmentInfoResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infos', full_name='milvus.proto.milvus.QuerySegmentInfoResponse.infos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5710,
  serialized_end=5835,
)


_REGISTERLINKRESPONSE = _descriptor.Descriptor(
  name='RegisterLinkResponse',
  full_name='milvus.proto.milvus.RegisterLinkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='milvus.proto.milvus.RegisterLinkResponse.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.RegisterLinkResponse.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5837,
  serialized_end=5951,
)

_CREATECOLLECTIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_DROPCOLLECTIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_HASCOLLECTIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_BOOLRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_STRINGRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_DESCRIBECOLLECTIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_DESCRIBECOLLECTIONRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_DESCRIBECOLLECTIONRESPONSE.fields_by_name['schema'].message_type = schema__pb2._COLLECTIONSCHEMA
_LOADCOLLECTIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_RELEASECOLLECTIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_COLLECTIONSTATSREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_COLLECTIONSTATSRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_COLLECTIONSTATSRESPONSE.fields_by_name['stats'].message_type = common__pb2._KEYVALUEPAIR
_SHOWCOLLECTIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_SHOWCOLLECTIONRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_CREATEPARTITIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_DROPPARTITIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_HASPARTITIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_LOADPARTITONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_RELEASEPARTITIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_PARTITIONSTATSREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_PARTITIONSTATSRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_PARTITIONSTATSRESPONSE.fields_by_name['stats'].message_type = common__pb2._KEYVALUEPAIR
_SHOWPARTITIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_SHOWPARTITIONRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_DESCRIBESEGMENTREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_DESCRIBESEGMENTRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_SHOWSEGMENTREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_SHOWSEGMENTRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_CREATEINDEXREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_CREATEINDEXREQUEST.fields_by_name['extra_params'].message_type = common__pb2._KEYVALUEPAIR
_DESCRIBEINDEXREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_INDEXDESCRIPTION.fields_by_name['params'].message_type = common__pb2._KEYVALUEPAIR
_DESCRIBEINDEXRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_DESCRIBEINDEXRESPONSE.fields_by_name['index_descriptions'].message_type = _INDEXDESCRIPTION
_INDEXSTATEREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_INDEXSTATERESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_INDEXSTATERESPONSE.fields_by_name['state'].enum_type = common__pb2._INDEXSTATE
_DROPINDEXREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_INSERTREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_INSERTREQUEST.fields_by_name['row_data'].message_type = common__pb2._BLOB
_INSERTRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_PLACEHOLDERVALUE.fields_by_name['type'].enum_type = _PLACEHOLDERTYPE
_PLACEHOLDERGROUP.fields_by_name['placeholders'].message_type = _PLACEHOLDERVALUE
_SEARCHREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_SEARCHRESULTS.fields_by_name['status'].message_type = common__pb2._STATUS
_FLUSHREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_PERSISTENTSEGMENTINFO.fields_by_name['state'].enum_type = common__pb2._SEGMENTSTATE
_PERSISTENTSEGMENTINFOREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_PERSISTENTSEGMENTINFORESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_PERSISTENTSEGMENTINFORESPONSE.fields_by_name['infos'].message_type = _PERSISTENTSEGMENTINFO
_QUERYSEGMENTINFOREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_QUERYSEGMENTINFORESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_QUERYSEGMENTINFORESPONSE.fields_by_name['infos'].message_type = _QUERYSEGMENTINFO
_REGISTERLINKRESPONSE.fields_by_name['address'].message_type = common__pb2._ADDRESS
_REGISTERLINKRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
DESCRIPTOR.message_types_by_name['CreateCollectionRequest'] = _CREATECOLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['DropCollectionRequest'] = _DROPCOLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['HasCollectionRequest'] = _HASCOLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['BoolResponse'] = _BOOLRESPONSE
DESCRIPTOR.message_types_by_name['StringResponse'] = _STRINGRESPONSE
DESCRIPTOR.message_types_by_name['DescribeCollectionRequest'] = _DESCRIBECOLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['DescribeCollectionResponse'] = _DESCRIBECOLLECTIONRESPONSE
DESCRIPTOR.message_types_by_name['LoadCollectionRequest'] = _LOADCOLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['ReleaseCollectionRequest'] = _RELEASECOLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['CollectionStatsRequest'] = _COLLECTIONSTATSREQUEST
DESCRIPTOR.message_types_by_name['CollectionStatsResponse'] = _COLLECTIONSTATSRESPONSE
DESCRIPTOR.message_types_by_name['ShowCollectionRequest'] = _SHOWCOLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['ShowCollectionResponse'] = _SHOWCOLLECTIONRESPONSE
DESCRIPTOR.message_types_by_name['CreatePartitionRequest'] = _CREATEPARTITIONREQUEST
DESCRIPTOR.message_types_by_name['DropPartitionRequest'] = _DROPPARTITIONREQUEST
DESCRIPTOR.message_types_by_name['HasPartitionRequest'] = _HASPARTITIONREQUEST
DESCRIPTOR.message_types_by_name['LoadPartitonRequest'] = _LOADPARTITONREQUEST
DESCRIPTOR.message_types_by_name['ReleasePartitionRequest'] = _RELEASEPARTITIONREQUEST
DESCRIPTOR.message_types_by_name['PartitionStatsRequest'] = _PARTITIONSTATSREQUEST
DESCRIPTOR.message_types_by_name['PartitionStatsResponse'] = _PARTITIONSTATSRESPONSE
DESCRIPTOR.message_types_by_name['ShowPartitionRequest'] = _SHOWPARTITIONREQUEST
DESCRIPTOR.message_types_by_name['ShowPartitionResponse'] = _SHOWPARTITIONRESPONSE
DESCRIPTOR.message_types_by_name['DescribeSegmentRequest'] = _DESCRIBESEGMENTREQUEST
DESCRIPTOR.message_types_by_name['DescribeSegmentResponse'] = _DESCRIBESEGMENTRESPONSE
DESCRIPTOR.message_types_by_name['ShowSegmentRequest'] = _SHOWSEGMENTREQUEST
DESCRIPTOR.message_types_by_name['ShowSegmentResponse'] = _SHOWSEGMENTRESPONSE
DESCRIPTOR.message_types_by_name['CreateIndexRequest'] = _CREATEINDEXREQUEST
DESCRIPTOR.message_types_by_name['DescribeIndexRequest'] = _DESCRIBEINDEXREQUEST
DESCRIPTOR.message_types_by_name['IndexDescription'] = _INDEXDESCRIPTION
DESCRIPTOR.message_types_by_name['DescribeIndexResponse'] = _DESCRIBEINDEXRESPONSE
DESCRIPTOR.message_types_by_name['IndexStateRequest'] = _INDEXSTATEREQUEST
DESCRIPTOR.message_types_by_name['IndexStateResponse'] = _INDEXSTATERESPONSE
DESCRIPTOR.message_types_by_name['DropIndexRequest'] = _DROPINDEXREQUEST
DESCRIPTOR.message_types_by_name['InsertRequest'] = _INSERTREQUEST
DESCRIPTOR.message_types_by_name['InsertResponse'] = _INSERTRESPONSE
DESCRIPTOR.message_types_by_name['PlaceholderValue'] = _PLACEHOLDERVALUE
DESCRIPTOR.message_types_by_name['PlaceholderGroup'] = _PLACEHOLDERGROUP
DESCRIPTOR.message_types_by_name['SearchRequest'] = _SEARCHREQUEST
DESCRIPTOR.message_types_by_name['Hits'] = _HITS
DESCRIPTOR.message_types_by_name['SearchResults'] = _SEARCHRESULTS
DESCRIPTOR.message_types_by_name['FlushRequest'] = _FLUSHREQUEST
DESCRIPTOR.message_types_by_name['PersistentSegmentInfo'] = _PERSISTENTSEGMENTINFO
DESCRIPTOR.message_types_by_name['PersistentSegmentInfoRequest'] = _PERSISTENTSEGMENTINFOREQUEST
DESCRIPTOR.message_types_by_name['PersistentSegmentInfoResponse'] = _PERSISTENTSEGMENTINFORESPONSE
DESCRIPTOR.message_types_by_name['QuerySegmentInfo'] = _QUERYSEGMENTINFO
DESCRIPTOR.message_types_by_name['QuerySegmentInfoRequest'] = _QUERYSEGMENTINFOREQUEST
DESCRIPTOR.message_types_by_name['QuerySegmentInfoResponse'] = _QUERYSEGMENTINFORESPONSE
DESCRIPTOR.message_types_by_name['RegisterLinkResponse'] = _REGISTERLINKRESPONSE
DESCRIPTOR.enum_types_by_name['PlaceholderType'] = _PLACEHOLDERTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateCollectionRequest = _reflection.GeneratedProtocolMessageType('CreateCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CreateCollectionRequest)
  })
_sym_db.RegisterMessage(CreateCollectionRequest)

DropCollectionRequest = _reflection.GeneratedProtocolMessageType('DropCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPCOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DropCollectionRequest)
  })
_sym_db.RegisterMessage(DropCollectionRequest)

HasCollectionRequest = _reflection.GeneratedProtocolMessageType('HasCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _HASCOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.HasCollectionRequest)
  })
_sym_db.RegisterMessage(HasCollectionRequest)

BoolResponse = _reflection.GeneratedProtocolMessageType('BoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _BOOLRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.BoolResponse)
  })
_sym_db.RegisterMessage(BoolResponse)

StringResponse = _reflection.GeneratedProtocolMessageType('StringResponse', (_message.Message,), {
  'DESCRIPTOR' : _STRINGRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.StringResponse)
  })
_sym_db.RegisterMessage(StringResponse)

DescribeCollectionRequest = _reflection.GeneratedProtocolMessageType('DescribeCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeCollectionRequest)
  })
_sym_db.RegisterMessage(DescribeCollectionRequest)

DescribeCollectionResponse = _reflection.GeneratedProtocolMessageType('DescribeCollectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECOLLECTIONRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeCollectionResponse)
  })
_sym_db.RegisterMessage(DescribeCollectionResponse)

LoadCollectionRequest = _reflection.GeneratedProtocolMessageType('LoadCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADCOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.LoadCollectionRequest)
  })
_sym_db.RegisterMessage(LoadCollectionRequest)

ReleaseCollectionRequest = _reflection.GeneratedProtocolMessageType('ReleaseCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _RELEASECOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ReleaseCollectionRequest)
  })
_sym_db.RegisterMessage(ReleaseCollectionRequest)

CollectionStatsRequest = _reflection.GeneratedProtocolMessageType('CollectionStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTIONSTATSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CollectionStatsRequest)
  })
_sym_db.RegisterMessage(CollectionStatsRequest)

CollectionStatsResponse = _reflection.GeneratedProtocolMessageType('CollectionStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTIONSTATSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CollectionStatsResponse)
  })
_sym_db.RegisterMessage(CollectionStatsResponse)

ShowCollectionRequest = _reflection.GeneratedProtocolMessageType('ShowCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHOWCOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowCollectionRequest)
  })
_sym_db.RegisterMessage(ShowCollectionRequest)

ShowCollectionResponse = _reflection.GeneratedProtocolMessageType('ShowCollectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHOWCOLLECTIONRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowCollectionResponse)
  })
_sym_db.RegisterMessage(ShowCollectionResponse)

CreatePartitionRequest = _reflection.GeneratedProtocolMessageType('CreatePartitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPARTITIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CreatePartitionRequest)
  })
_sym_db.RegisterMessage(CreatePartitionRequest)

DropPartitionRequest = _reflection.GeneratedProtocolMessageType('DropPartitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPPARTITIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DropPartitionRequest)
  })
_sym_db.RegisterMessage(DropPartitionRequest)

HasPartitionRequest = _reflection.GeneratedProtocolMessageType('HasPartitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _HASPARTITIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.HasPartitionRequest)
  })
_sym_db.RegisterMessage(HasPartitionRequest)

LoadPartitonRequest = _reflection.GeneratedProtocolMessageType('LoadPartitonRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADPARTITONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.LoadPartitonRequest)
  })
_sym_db.RegisterMessage(LoadPartitonRequest)

ReleasePartitionRequest = _reflection.GeneratedProtocolMessageType('ReleasePartitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _RELEASEPARTITIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ReleasePartitionRequest)
  })
_sym_db.RegisterMessage(ReleasePartitionRequest)

PartitionStatsRequest = _reflection.GeneratedProtocolMessageType('PartitionStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONSTATSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.PartitionStatsRequest)
  })
_sym_db.RegisterMessage(PartitionStatsRequest)

PartitionStatsResponse = _reflection.GeneratedProtocolMessageType('PartitionStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONSTATSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.PartitionStatsResponse)
  })
_sym_db.RegisterMessage(PartitionStatsResponse)

ShowPartitionRequest = _reflection.GeneratedProtocolMessageType('ShowPartitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHOWPARTITIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowPartitionRequest)
  })
_sym_db.RegisterMessage(ShowPartitionRequest)

ShowPartitionResponse = _reflection.GeneratedProtocolMessageType('ShowPartitionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHOWPARTITIONRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowPartitionResponse)
  })
_sym_db.RegisterMessage(ShowPartitionResponse)

DescribeSegmentRequest = _reflection.GeneratedProtocolMessageType('DescribeSegmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESEGMENTREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeSegmentRequest)
  })
_sym_db.RegisterMessage(DescribeSegmentRequest)

DescribeSegmentResponse = _reflection.GeneratedProtocolMessageType('DescribeSegmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESEGMENTRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeSegmentResponse)
  })
_sym_db.RegisterMessage(DescribeSegmentResponse)

ShowSegmentRequest = _reflection.GeneratedProtocolMessageType('ShowSegmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHOWSEGMENTREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowSegmentRequest)
  })
_sym_db.RegisterMessage(ShowSegmentRequest)

ShowSegmentResponse = _reflection.GeneratedProtocolMessageType('ShowSegmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHOWSEGMENTRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowSegmentResponse)
  })
_sym_db.RegisterMessage(ShowSegmentResponse)

CreateIndexRequest = _reflection.GeneratedProtocolMessageType('CreateIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEINDEXREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CreateIndexRequest)
  })
_sym_db.RegisterMessage(CreateIndexRequest)

DescribeIndexRequest = _reflection.GeneratedProtocolMessageType('DescribeIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINDEXREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeIndexRequest)
  })
_sym_db.RegisterMessage(DescribeIndexRequest)

IndexDescription = _reflection.GeneratedProtocolMessageType('IndexDescription', (_message.Message,), {
  'DESCRIPTOR' : _INDEXDESCRIPTION,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.IndexDescription)
  })
_sym_db.RegisterMessage(IndexDescription)

DescribeIndexResponse = _reflection.GeneratedProtocolMessageType('DescribeIndexResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINDEXRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeIndexResponse)
  })
_sym_db.RegisterMessage(DescribeIndexResponse)

IndexStateRequest = _reflection.GeneratedProtocolMessageType('IndexStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _INDEXSTATEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.IndexStateRequest)
  })
_sym_db.RegisterMessage(IndexStateRequest)

IndexStateResponse = _reflection.GeneratedProtocolMessageType('IndexStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _INDEXSTATERESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.IndexStateResponse)
  })
_sym_db.RegisterMessage(IndexStateResponse)

DropIndexRequest = _reflection.GeneratedProtocolMessageType('DropIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPINDEXREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DropIndexRequest)
  })
_sym_db.RegisterMessage(DropIndexRequest)

InsertRequest = _reflection.GeneratedProtocolMessageType('InsertRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSERTREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.InsertRequest)
  })
_sym_db.RegisterMessage(InsertRequest)

InsertResponse = _reflection.GeneratedProtocolMessageType('InsertResponse', (_message.Message,), {
  'DESCRIPTOR' : _INSERTRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.InsertResponse)
  })
_sym_db.RegisterMessage(InsertResponse)

PlaceholderValue = _reflection.GeneratedProtocolMessageType('PlaceholderValue', (_message.Message,), {
  'DESCRIPTOR' : _PLACEHOLDERVALUE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.PlaceholderValue)
  })
_sym_db.RegisterMessage(PlaceholderValue)

PlaceholderGroup = _reflection.GeneratedProtocolMessageType('PlaceholderGroup', (_message.Message,), {
  'DESCRIPTOR' : _PLACEHOLDERGROUP,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.PlaceholderGroup)
  })
_sym_db.RegisterMessage(PlaceholderGroup)

SearchRequest = _reflection.GeneratedProtocolMessageType('SearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SearchRequest)
  })
_sym_db.RegisterMessage(SearchRequest)

Hits = _reflection.GeneratedProtocolMessageType('Hits', (_message.Message,), {
  'DESCRIPTOR' : _HITS,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.Hits)
  })
_sym_db.RegisterMessage(Hits)

SearchResults = _reflection.GeneratedProtocolMessageType('SearchResults', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHRESULTS,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SearchResults)
  })
_sym_db.RegisterMessage(SearchResults)

FlushRequest = _reflection.GeneratedProtocolMessageType('FlushRequest', (_message.Message,), {
  'DESCRIPTOR' : _FLUSHREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.FlushRequest)
  })
_sym_db.RegisterMessage(FlushRequest)

PersistentSegmentInfo = _reflection.GeneratedProtocolMessageType('PersistentSegmentInfo', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTSEGMENTINFO,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.PersistentSegmentInfo)
  })
_sym_db.RegisterMessage(PersistentSegmentInfo)

PersistentSegmentInfoRequest = _reflection.GeneratedProtocolMessageType('PersistentSegmentInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTSEGMENTINFOREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.PersistentSegmentInfoRequest)
  })
_sym_db.RegisterMessage(PersistentSegmentInfoRequest)

PersistentSegmentInfoResponse = _reflection.GeneratedProtocolMessageType('PersistentSegmentInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTSEGMENTINFORESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.PersistentSegmentInfoResponse)
  })
_sym_db.RegisterMessage(PersistentSegmentInfoResponse)

QuerySegmentInfo = _reflection.GeneratedProtocolMessageType('QuerySegmentInfo', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSEGMENTINFO,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.QuerySegmentInfo)
  })
_sym_db.RegisterMessage(QuerySegmentInfo)

QuerySegmentInfoRequest = _reflection.GeneratedProtocolMessageType('QuerySegmentInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSEGMENTINFOREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.QuerySegmentInfoRequest)
  })
_sym_db.RegisterMessage(QuerySegmentInfoRequest)

QuerySegmentInfoResponse = _reflection.GeneratedProtocolMessageType('QuerySegmentInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSEGMENTINFORESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.QuerySegmentInfoResponse)
  })
_sym_db.RegisterMessage(QuerySegmentInfoResponse)

RegisterLinkResponse = _reflection.GeneratedProtocolMessageType('RegisterLinkResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERLINKRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.RegisterLinkResponse)
  })
_sym_db.RegisterMessage(RegisterLinkResponse)


DESCRIPTOR._options = None

_MILVUSSERVICE = _descriptor.ServiceDescriptor(
  name='MilvusService',
  full_name='milvus.proto.milvus.MilvusService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=6020,
  serialized_end=8514,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateCollection',
    full_name='milvus.proto.milvus.MilvusService.CreateCollection',
    index=0,
    containing_service=None,
    input_type=_CREATECOLLECTIONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DropCollection',
    full_name='milvus.proto.milvus.MilvusService.DropCollection',
    index=1,
    containing_service=None,
    input_type=_DROPCOLLECTIONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HasCollection',
    full_name='milvus.proto.milvus.MilvusService.HasCollection',
    index=2,
    containing_service=None,
    input_type=_HASCOLLECTIONREQUEST,
    output_type=_BOOLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LoadCollection',
    full_name='milvus.proto.milvus.MilvusService.LoadCollection',
    index=3,
    containing_service=None,
    input_type=_LOADCOLLECTIONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReleaseCollection',
    full_name='milvus.proto.milvus.MilvusService.ReleaseCollection',
    index=4,
    containing_service=None,
    input_type=_RELEASECOLLECTIONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeCollection',
    full_name='milvus.proto.milvus.MilvusService.DescribeCollection',
    index=5,
    containing_service=None,
    input_type=_DESCRIBECOLLECTIONREQUEST,
    output_type=_DESCRIBECOLLECTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetCollectionStatistics',
    full_name='milvus.proto.milvus.MilvusService.GetCollectionStatistics',
    index=6,
    containing_service=None,
    input_type=_COLLECTIONSTATSREQUEST,
    output_type=_COLLECTIONSTATSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ShowCollections',
    full_name='milvus.proto.milvus.MilvusService.ShowCollections',
    index=7,
    containing_service=None,
    input_type=_SHOWCOLLECTIONREQUEST,
    output_type=_SHOWCOLLECTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePartition',
    full_name='milvus.proto.milvus.MilvusService.CreatePartition',
    index=8,
    containing_service=None,
    input_type=_CREATEPARTITIONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DropPartition',
    full_name='milvus.proto.milvus.MilvusService.DropPartition',
    index=9,
    containing_service=None,
    input_type=_DROPPARTITIONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HasPartition',
    full_name='milvus.proto.milvus.MilvusService.HasPartition',
    index=10,
    containing_service=None,
    input_type=_HASPARTITIONREQUEST,
    output_type=_BOOLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LoadPartitions',
    full_name='milvus.proto.milvus.MilvusService.LoadPartitions',
    index=11,
    containing_service=None,
    input_type=_LOADPARTITONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReleasePartitions',
    full_name='milvus.proto.milvus.MilvusService.ReleasePartitions',
    index=12,
    containing_service=None,
    input_type=_RELEASEPARTITIONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetPartitionStatistics',
    full_name='milvus.proto.milvus.MilvusService.GetPartitionStatistics',
    index=13,
    containing_service=None,
    input_type=_PARTITIONSTATSREQUEST,
    output_type=_PARTITIONSTATSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ShowPartitions',
    full_name='milvus.proto.milvus.MilvusService.ShowPartitions',
    index=14,
    containing_service=None,
    input_type=_SHOWPARTITIONREQUEST,
    output_type=_SHOWPARTITIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateIndex',
    full_name='milvus.proto.milvus.MilvusService.CreateIndex',
    index=15,
    containing_service=None,
    input_type=_CREATEINDEXREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeIndex',
    full_name='milvus.proto.milvus.MilvusService.DescribeIndex',
    index=16,
    containing_service=None,
    input_type=_DESCRIBEINDEXREQUEST,
    output_type=_DESCRIBEINDEXRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetIndexState',
    full_name='milvus.proto.milvus.MilvusService.GetIndexState',
    index=17,
    containing_service=None,
    input_type=_INDEXSTATEREQUEST,
    output_type=_INDEXSTATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DropIndex',
    full_name='milvus.proto.milvus.MilvusService.DropIndex',
    index=18,
    containing_service=None,
    input_type=_DROPINDEXREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Insert',
    full_name='milvus.proto.milvus.MilvusService.Insert',
    index=19,
    containing_service=None,
    input_type=_INSERTREQUEST,
    output_type=_INSERTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Search',
    full_name='milvus.proto.milvus.MilvusService.Search',
    index=20,
    containing_service=None,
    input_type=_SEARCHREQUEST,
    output_type=_SEARCHRESULTS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Flush',
    full_name='milvus.proto.milvus.MilvusService.Flush',
    index=21,
    containing_service=None,
    input_type=_FLUSHREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDdChannel',
    full_name='milvus.proto.milvus.MilvusService.GetDdChannel',
    index=22,
    containing_service=None,
    input_type=common__pb2._EMPTY,
    output_type=_STRINGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetPersistentSegmentInfo',
    full_name='milvus.proto.milvus.MilvusService.GetPersistentSegmentInfo',
    index=23,
    containing_service=None,
    input_type=_PERSISTENTSEGMENTINFOREQUEST,
    output_type=_PERSISTENTSEGMENTINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetQuerySegmentInfo',
    full_name='milvus.proto.milvus.MilvusService.GetQuerySegmentInfo',
    index=24,
    containing_service=None,
    input_type=_QUERYSEGMENTINFOREQUEST,
    output_type=_QUERYSEGMENTINFORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MILVUSSERVICE)

DESCRIPTOR.services_by_name['MilvusService'] = _MILVUSSERVICE


_PROXYSERVICE = _descriptor.ServiceDescriptor(
  name='ProxyService',
  full_name='milvus.proto.milvus.ProxyService',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=8516,
  serialized_end=8619,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterLink',
    full_name='milvus.proto.milvus.ProxyService.RegisterLink',
    index=0,
    containing_service=None,
    input_type=common__pb2._EMPTY,
    output_type=_REGISTERLINKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROXYSERVICE)

DESCRIPTOR.services_by_name['ProxyService'] = _PROXYSERVICE

# @@protoc_insertion_point(module_scope)
